@@ -1,8 +1,8 @@
-import ejcli._http.ejudge, ejcli._http.ejudge.ejfuse, ejcli._http.pcms, ejcli._http.jjs, ejcli._http.informatics, ejcli._http.informatics_new, ejcli._http.codeforces, ejcli._http.gcj, urllib.request
+import ejcli._http.ejudge, ejcli._http.ejudge.ejfuse, ejcli._http.pcms, ejcli._http.jjs, ejcli._http.informatics, ejcli._http.informatics_new, ejcli._http.codeforces, ejcli._http.gcj, ejcli._http.cache, urllib.request
 from ejcli._http.ejudge import contest_name
 from ejcli.error import EJError
 
-backend_path = [ejcli._http.ejudge.ejfuse.EJFuse, ejcli._http.jjs.JJS, ejcli._http.informatics.Informatics, ejcli._http.informatics_new.Informatics, ejcli._http.codeforces.CodeForces, ejcli._http.gcj.GCJ, ejcli._http.pcms.PCMS, ejcli._http.ejudge.Ejudge]
+backend_path = [ejcli._http.cache.AggressiveCacheBackend, ejcli._http.ejudge.ejfuse.EJFuse, ejcli._http.jjs.JJS, ejcli._http.informatics.Informatics, ejcli._http.informatics_new.Informatics, ejcli._http.codeforces.CodeForces, ejcli._http.gcj.GCJ, ejcli._http.pcms.PCMS, ejcli._http.ejudge.Ejudge]
 
 def login(url, login, password, **kwds):
     for i in backend_path:
